@@ -41,10 +41,10 @@ class Game:
         else:
             assert 1 <= seen_from <= 4, "The seen_from has to be between 1 and 4. Indicating the player the pieces are seen from and the nemys are seen from"
             # Get where the players piece are
-            pieces = self.players[seen_from].get_pieces()
+            pieces = self.players[seen_from - 1].get_pieces()
             # Get where the enemy's piece are
-            enemy_pieces = [self.players[e].get_pieces() for e in self.enemys_order[seen_from]]
-        return np.array(pieces), np.array(enemy_pieces)
+            enemy_pieces = [self.players[e].get_pieces() for e in self.enemys_order[seen_from - 1]]
+        return pieces, enemy_pieces
 
     def __add_to_hist(self):
         pieces = self.get_pieces()
@@ -68,7 +68,7 @@ class Game:
         self.current_move_pieces = move_pieces
 
         # Get where the players piece are and the enemy's piece are
-        player_pieces, enemy_pieces = self.get_pieces(player_idx)
+        player_pieces, enemy_pieces = self.get_pieces(player_idx+1)
         self.current_enemys = enemy_pieces
         # Check if the player is a winner
         player_is_a_winner = player.player_winner()
